isLightMode property
Returns true if the actual theme used in the app is light.
Implementation
@Deprecated("Use `themeMode` instead")
bool get isLightMode => themeMode == ThemeMode.light;
Returns true if the actual theme used in the app is light.
@Deprecated("Use `themeMode` instead")
bool get isLightMode => themeMode == ThemeMode.light;