loadingWidget property
You can use this widget to specify what to show during ThemeProvider initialization.
If null an empty Scaffold will be shown.
Implementation
final Widget? loadingWidget;
You can use this widget to specify what to show during ThemeProvider initialization.
If null an empty Scaffold will be shown.
final Widget? loadingWidget;