child property

Widget? child
final

By default, the DropdownSelector shows a custom widget to tap to open the dropdown. This widget can be overwritten by passing a custom child

Implementation

final Widget? child;