items property

Future<List<T>> Function() items
final

The list of items to show in the dropdown. It's a Future, so that the dropdown itself is responsbile of waiting the result while loading data.

Implementation

final Future<List<T>> Function() items;