ExpandableText class

Multiline text that can be eventually expanded with a button to show more lines

Inheritance

Constructors

ExpandableText({Key? key, required TextSpan textSpan, required int maxLines, Text seeMore = const Text("Show more", style: TextStyle(fontWeight: FontWeight.bold, decoration: TextDecoration.underline)), Text seeLess = const Text("Show less", style: TextStyle(fontWeight: FontWeight.bold, decoration: TextDecoration.underline))})
Multiline text that can be eventually expanded with a button to show more lines.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int
The number of lines to show initially to truncate the text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seeLess Text
The text to show at the end of the truncated textSpan to eventually manage the collapse logic. Defaults to Show less
final
seeMore Text
The text to show at the end of the truncated textSpan to eventually manage the expand logic. Defaults to Show more
final
textSpan TextSpan
The text to truncate depending on maxLines to show
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited