seeLess property
The text to show at the end of the truncated textSpan to eventually manage
the collapse logic. Defaults to Show less
Implementation
final Text seeLess;
The text to show at the end of the truncated textSpan to eventually manage
the collapse logic. Defaults to Show less
final Text seeLess;