seeMore property
The text to show at the end of the truncated textSpan to eventually manage
the expand logic. Defaults to Show more
Implementation
final Text seeMore;
The text to show at the end of the truncated textSpan to eventually manage
the expand logic. Defaults to Show more
final Text seeMore;