PageSkeleton class

Default skeleton page, with SafeArea, scrollbar and padding.

Inheritance

Constructors

PageSkeleton({Key? key, required Widget body, PreferredSizeWidget? appBar, Widget? floatingActionButton, Widget? topWidget, bool removePadding = false})
Creates a scaffold page with SafeArea, simple scroll bar and a default inner padding. Its content will expand in width until a max page width set in this uikit.
const

Properties

appBar PreferredSizeWidget?
Optionally, an appbar can be provided as a custom widget.
final
body Widget
The body to show in the scaffold page.
final
floatingActionButton Widget?
Optionally, a FAB can be provided as a custom widget. If not specified, no FAB will be added.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
removePadding bool
If true removes default padding in page. Defaults to false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topWidget Widget?
Optionally, a widget to display on top of the page (eventually under an AppBar) can be provided. It will expand for entire screen's width, without considering the max page width set in this uikit.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited