PageSkeleton constructor

const PageSkeleton({
  1. Key? key,
  2. required Widget body,
  3. PreferredSizeWidget? appBar,
  4. Widget? floatingActionButton,
  5. Widget? topWidget,
  6. bool removePadding = false,
})

Creates a scaffold page with SafeArea, simple scroll bar and a default inner padding. Its content will expand in width until a max page width set in this uikit.

Eventually, an appbar and a FAB can be provided as custom widgets, so as a widget can be provided to be shown under on top of the page extended beyond the max page width.

Implementation

const PageSkeleton(
    {Key? key,
    required this.body,
    this.appBar,
    this.floatingActionButton,
    this.topWidget,
    this.removePadding = false})
    : super(key: key);