removeMargin property
If true removes the default external margins of the ShadowBox container.
Defaults to false.
Implementation
final bool removeMargin;
If true removes the default external margins of the ShadowBox container.
Defaults to false.
final bool removeMargin;