ShadowBoxWithTitle class
A card-styled container widget with rounded corners, shadows on the background and eventually an external margin. It shows a title.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ShadowBoxWithTitle
Constructors
- ShadowBoxWithTitle({Key? key, required Widget child, bool removeMargin = false, bool removeInnerPadding = false, required Widget title, bool shouldAllowHiding = false, bool initiallyShowChild = true})
-
Creates a card-styled container widget with rounded corners, shadows on the background
and eventually an external margin.
const
Properties
- child → Widget
-
The child widget to append inside the container.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initiallyShowChild → bool
-
If
trueshows the child, otherwise hides it initially by default. Defaults totrue.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- removeInnerPadding → bool
-
If
trueremoves the padding on top and bottom ofchildin ShadowBox. Defaults tofalse.final - removeMargin → bool
-
If
trueremoves the default external margins of the ShadowBox container. Defaults tofalse.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldAllowHiding → bool
-
If
trueadds an icon button to show/hide childfinal - title → Widget
-
The widget to show on top of the shadow box.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< StatefulWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited