ShadowBoxWithTitle constructor

const ShadowBoxWithTitle({
  1. Key? key,
  2. required Widget child,
  3. bool removeMargin = false,
  4. bool removeInnerPadding = false,
  5. required Widget title,
  6. bool shouldAllowHiding = false,
  7. bool initiallyShowChild = true,
})

Creates a card-styled container widget with rounded corners, shadows on the background and eventually an external margin.

It has a default margin that can be removed by setting removeMargin to true. It has also a title and eventually an icon button to hide/show content.

Implementation

const ShadowBoxWithTitle({
  Key? key,
  required this.child,
  this.removeMargin = false,
  this.removeInnerPadding = false,
  required this.title,
  this.shouldAllowHiding = false,
  this.initiallyShowChild = true,
}) : super(key: key);