initiallyShowChild property
If true shows the child, otherwise hides it initially by default.
Defaults to true.
Implementation
final bool initiallyShowChild;
If true shows the child, otherwise hides it initially by default.
Defaults to true.
final bool initiallyShowChild;