removeInnerPadding property
If true removes the padding on top and bottom of child in ShadowBox.
Defaults to false.
Implementation
final bool removeInnerPadding;
If true removes the padding on top and bottom of child in ShadowBox.
Defaults to false.
final bool removeInnerPadding;