Themes class
This class manages dark and light theme data.
Constructors
- Themes()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- darkTheme → ThemeData
-
Dark theme data, with specifications for colors, text fonts,
schemes, themes and all kinds of properties for widgets.
final
- lightTheme → ThemeData
-
Light theme data, with specifications for colors, text fonts,
schemes, themes and all kinds of properties for widgets.
final