allowMultiselection property
If true, checkboxes are shown in the dropdown to allow multiselection. Note that the onSelectItem callback is called every time the user flags a checkbox, so it's developer responsability to manage selected items lists (i.e. select/deselect items)
Implementation
final bool allowMultiselection;