onSelectItemOverview property
void Function(T item)?
onSelectItemOverview
final
If this method is not null, a "detail" icon is shown on the right side of each dropdown item tile, to eventually do something such as opening a modal detail.
Implementation
final void Function(T item)? onSelectItemOverview;