selectedItemLabel property
The label to show in the default dropdown box when the dropdown is closed.
Defautls to "Seleziona". It should be updated every time the user selects an item,
eventually with a setState, so that the label reflects the user choice.
Implementation
final String? selectedItemLabel;