onChangeText property
The String argument is the actual text in the search bar.
This method is called whenever the text changes.
It can be used, for instance, to filter content depending on text input.
Implementation
final Function(String) onChangeText;