topWidget property

Widget? topWidget
final

Optionally, a widget to display on top of the page (eventually under an AppBar) can be provided. It will expand for entire screen's width, without considering the max page width set in this uikit.

Implementation

final Widget? topWidget;