ShadowBox constructor
Creates a card-styled container widget with rounded corners, shadows on the background and eventually an external margin.
It has a default margin that can be removed by setting removeMargin to true.
Implementation
const ShadowBox({
Key? key,
required this.child,
this.removeMargin = false,
}) : super(key: key);