TimePicker class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TimePicker
Constructors
- TimePicker({Key? key, bool roundBorder = false, double maxWidth = 180, double maxHeight = 200, Color colorBackground = Colors.transparent, TextStyle style = const TextStyle(color: Colors.black, fontSize: 12, fontWeight: FontWeight.normal), TextStyle selectedStyle = const TextStyle(color: Colors.black, fontSize: 16, fontWeight: FontWeight.bold), required String hoursSemanticLabel, required String minutesSemanticLabel, double minutesOffAxisFraction = 1.0, double hoursOffAxisFraction = -1.0, double diameterRatio = 1.1, double itemExtent = 25.0, DateTime? initialTime, required dynamic onTimeSelected(DateTime), bool selectAtStart = false, Duration? debouncingWindow = const Duration(milliseconds: 300), double separatorPadding = 0.0})
-
const
Properties
- colorBackground → Color
-
final
- debouncingWindow → Duration?
-
final
- diameterRatio → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoursOffAxisFraction → double
-
final
- hoursSemanticLabel → String
-
final
- initialTime → DateTime?
-
final
- itemExtent → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxHeight → double
-
final
- maxWidth → double
-
final
- minutesOffAxisFraction → double
-
final
- minutesSemanticLabel → String
-
final
- onTimeSelected → dynamic Function(DateTime)
-
final
- roundBorder → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectAtStart → bool
-
final
- selectedStyle → TextStyle
-
final
- separatorPadding → double
-
final
- style → TextStyle
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TimePicker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited